function [bvp,info]=setBVPPoisson2D_ex01(N,verbose)
  if nargin<=1, verbose=0;end
  uex=@(x,y) cos(x-y).*sin(x+y)+exp(-(x.^2+y.^2));
  f=@(x,y) -4*x.^2.*exp(-x.^2-y.^2) - 4*y.^2.*exp(-x.^2-y.^2) + 4*cos(x-y).*sin(x+y) + 4*exp(-x.^2-y.^2);
  
  if verbose>=1
    fprintf('------------------------------------------------------\n'); 
    fprintf('      2D Poisson B.V.P. problem on unit square:\n');
    fprintf('               -Delta(u) = f\n')
    fprintf(' with  \n');
    fprintf('    * Dirichlet boundary conditions on [1,2,3,4]\n');
    fprintf(' Exact solution : %s\n',func2str(uex));
    fprintf('------------------------------------------------------\n');
    if verbose==10, return;end
  end

  if verbose>=2,fprintf('1. Setting the mesh using HyperCube function\n');end
  tstart=tic();
  Th=fc_simesh.HyperCube(2,N);
  tcpu(1)=toc(tstart);
  if verbose>=2
    fprintf('     Mesh sizes : nq=%d, h=%.3e\n',Th.nq,Th.get_h());
    fprintf('2. Setting 2D Poisson BVP problem\n');
  end
  tstart=tic();
  Lop=Loperator(2,2,{1,0;0,1},[],[],[]);
  pde=PDEelt(Lop,f);
  bvp=BVP(Th,pde);
  bvp.setDirichlet( 1, uex);
  bvp.setDirichlet( 2, uex);
  bvp.setDirichlet( 3, uex);
  bvp.setDirichlet( 4, uex);
  tcpu(2)=toc(tstart);

  info.solex=uex;
  info.f=f;
  info.tcpu=tcpu;
end